==> haskell-stack-1.4.0-50-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.4.0
id: stack-1.4.0-8ZOoYP29PHkBBc77OOBSLw
key: stack-1.4.0-8ZOoYP29PHkBBc77OOBSLw
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.ScriptParser Stack.Options.SolverParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.PackageIndex Stack.Path Stack.PrettyPrint
    Stack.Runners Stack.Script Stack.SDist Stack.Setup
    Stack.Setup.Installed Stack.SetupCmd Stack.Sig Stack.Sig.GPG
    Stack.Sig.Sign Stack.Solver Stack.Types.Build Stack.Types.BuildPlan
    Stack.Types.CompilerBuild Stack.Types.Urls Stack.Types.Compiler
    Stack.Types.Config Stack.Types.Config.Build Stack.Types.Docker
    Stack.Types.FlagName Stack.Types.GhcPkgId Stack.Types.Image
    Stack.Types.Internal Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageDump Stack.Types.PackageIdentifier
    Stack.Types.PackageIndex Stack.Types.PackageName
    Stack.Types.Resolver Stack.Types.Sig Stack.Types.StackT
    Stack.Types.TemplateName Stack.Types.Version Stack.Upgrade
    Stack.Upload Text.PrettyPrint.Leijen.Extended System.Process.Log
    System.Process.PagerEditor System.Process.Read System.Process.Run
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
abi: d830cb0af25d10e434fef326c9df1cec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/stack-1.4.0
hs-libraries: HSstack-1.4.0-8ZOoYP29PHkBBc77OOBSLw
depends:
    Cabal-1.24.0.0 aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-JxYMIQKerlKB4kL00PwuOT
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-ASXD1Y7ORRDJz1X54jUL8d containers-0.5.7.1
    cryptonite-0.22-BghVPg0sVunAfXbG7gt71d
    cryptonite-conduit-0.2.0-4mAgdTNMZcMH1XwjTp3zFu deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-5f7aE9WqhDuIG4WZ3BCho5
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-F3SZJZ6KmEOGHbHJYEMCVP
    generic-deriving-1.11.2-QHIzAscXeYC4Er9z19sEy
    hackage-security-0.5.2.2-9MnF6D5H3VHIkpJdtoEuhq
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    hastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
    hit-0.6.3-KNmlSo1leCPINnDaARwSCM
    hpack-0.17.0-2FNvScGu8JiJ8yKCbwbiFH hpc-0.6.0.3
    http-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
    http-client-tls-0.3.4.2-F12wrJelZkfIkqt9nK8Chw
    http-conduit-2.2.3.1-ImPazU3masKCgetMJMrLX8
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    lifted-async-0.9.1.1-Brov1Kj03bM5McrEOvXrGi
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.24-FiZCIIbO7ui1TJ2Lwn7uL8
    monad-unlift-0.2.0-54TR42aNudbB2s18jYfbjS
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    path-0.5.13-K7V1JTWd0h5EsaktM7q5nZ
    path-io-1.2.2-DIG5GUsqtpVKbE7boD97c
    persistent-2.6.1-HxYaFVJlIzreSYWaz96wU
    persistent-sqlite-2.6.2-6bsJZiPygcZ2dwWpMkMmNb
    persistent-template-2.5.2-7R6PvQO7gEQHuwmIzRpgDB
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-3iiBYKiN3pfHfdUvrlJC14
    regex-applicative-text-0.1.0.1-38rcZcyG4EMFvQ12jRt4xV
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    safe-exceptions-0.1.5.0-KprIFH6jKWj4auk5wxb686
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    split-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    store-0.4.3.1-7py1lCbby7TJDldL382L3C
    store-core-0.4.1-4OvCT8JxHHJHspRdxW3rXv
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-binary-0.2.1.1-6SPK6a88IPhHHsLZYIQFEq
    text-metrics-0.2.0-Hn6WpAXJzhNBCvatQNDxSh time-1.6.0.1
    tls-1.3.10-CAbBElcTTLo1smrQ4ce9Lb transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-binary-instances-0.2.3.5-7f4DOuSrzuCGDSfkgQUKlt
    yaml-0.8.22.1-12E7gJJouZU1HVI6hodIEy
    zip-archive-0.3.0.6-Ig0t72Nj5zm5vunOYcd6Nx
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stack-1.4.0-54-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.4.0
id: stack-1.4.0-8TdyJFyrUcgJ177ZS0bAwo
key: stack-1.4.0-8TdyJFyrUcgJ177ZS0bAwo
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.ScriptParser Stack.Options.SolverParser
    Stack.Options.TestParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.PackageIndex Stack.Path Stack.PrettyPrint
    Stack.Runners Stack.Script Stack.SDist Stack.Setup
    Stack.Setup.Installed Stack.SetupCmd Stack.Sig Stack.Sig.GPG
    Stack.Sig.Sign Stack.Solver Stack.Types.Build Stack.Types.BuildPlan
    Stack.Types.CompilerBuild Stack.Types.Urls Stack.Types.Compiler
    Stack.Types.Config Stack.Types.Config.Build Stack.Types.Docker
    Stack.Types.FlagName Stack.Types.GhcPkgId Stack.Types.Image
    Stack.Types.Internal Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageDump Stack.Types.PackageIdentifier
    Stack.Types.PackageIndex Stack.Types.PackageName
    Stack.Types.Resolver Stack.Types.Sig Stack.Types.StackT
    Stack.Types.TemplateName Stack.Types.Version Stack.Upgrade
    Stack.Upload Text.PrettyPrint.Leijen.Extended System.Process.Log
    System.Process.PagerEditor System.Process.Read System.Process.Run
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
abi: fff8086dab8c60354635a2cb3746b1d5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.4.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/stack-1.4.0
hs-libraries: HSstack-1.4.0-8TdyJFyrUcgJ177ZS0bAwo
depends:
    Cabal-1.24.0.0 aeson-1.1.2.0-KSzOWeOw6cI7ymVovOXtxy
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.3-EZA1Pyq8DBj2Viel0l4pEB
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-ElSKQLfL52pBseBl89Tv0i
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-LbHEhSYrKrIKl2iEItQ5UA containers-0.5.7.1
    cryptonite-0.23-IZJ66Y8jjDgmndLH4VfVr
    cryptonite-conduit-0.2.0-DGa6Ybn3yZb9wzcq7zM2LR deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-5f7aE9WqhDuIG4WZ3BCho5
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
    fast-logger-2.4.10-1KSNxjE2NJ14puKDEfe1S4
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-BqlufDCrIeNAMMQtJtCOHF
    generic-deriving-1.11.2-QHIzAscXeYC4Er9z19sEy
    hackage-security-0.5.2.2-DjgbnDbKY7k8EibYRWanmF
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    hastache-0.6.1-INBEYETTDYrFnEdQooIIgl
    hit-0.6.3-CpofqamtC8c8Sy92SjvZ1F hpack-0.17.0-4zotrxRYoWlWAb8WKMaD0
    hpc-0.6.0.3 http-client-0.5.6.1-DSQ8eJPS1kI6DRuwfPV1nA
    http-client-tls-0.3.4.2-Jc1twMWCtNA4lKBByPDnzp
    http-conduit-2.2.3.1-BOJG5MQUuJ18W496EbHKHZ
    http-types-0.9.1-CqrySqSyfUpJeibsqMm4gL
    lifted-async-0.9.1.1-G8ZEHDZlasn8wdM80S3ABt
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.24-3TRZywB0PN0FNMMmN151zF
    monad-unlift-0.2.0-Iihww1JvYeNENum9UaSwjW
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.2.0-2f8ecj6rdMuFtm9J78ebBE
    path-0.5.13-EOwpNQg6bbO10vV1LJ3Zpe
    path-io-1.2.2-2sHXQnOUv9p5UHCk59XVDM
    persistent-2.6.1-AMgInoZf6p1h9wbySJ8FR
    persistent-sqlite-2.6.2-GihvhblpFXfKTyyGVjeeoL
    persistent-template-2.5.2-9tYKUil4aGDI4wu1YdAHB8
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-9nMHnPOJKxxKo4Q8p5N8ne
    regex-applicative-text-0.1.0.1-EqLJQ6CRgOKHNHiekY9mPZ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    safe-exceptions-0.1.5.0-KprIFH6jKWj4auk5wxb686
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    split-0.2.3.2-1dCEe3bkR6E9uyZt6jsXK
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    store-0.4.3.1-GlJz9kjb2kSBDpUelzHNU6
    store-core-0.4.1-Ey4EpELhDqFAlVc74XVbbZ
    streaming-commons-0.1.17-2RhPlNIoNU5IoFWI4FKVKo
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    text-binary-0.2.1.1-Hkj6oz2uZWkDQMhITvGGj1
    text-metrics-0.2.0-BLCHYH7vuwm4ZQtWq2aZfi time-1.6.0.1
    tls-1.3.10-Blcr4Z6u3dE5lnvWI6RAH7 transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0 unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-binary-instances-0.2.3.5-7f4DOuSrzuCGDSfkgQUKlt
    yaml-0.8.23-8QNs3yIAJ968Qiwin5SBPe
    zip-archive-0.3.0.6-JjkOHEal90LKpFodcWqmlO
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
